ProducerActivity

Enum ProducerActivity 

pub enum ProducerActivity {
    Active,
    Inactive,
}
producer-side transport activity state

this is transport execution policy, not room membership the room remains responsible for deciding whether a source should be considered published or visible to participants

Variants



Active

RTP from this producer should be forwarded when routes allow it



Inactive

RTP from this producer should not be forwarded until reactivated

Implementations

Source

impl ProducerActivity

pub const fn from_active(active: bool) -> ProducerActivity

pub const fn is_active(self) -> bool